## CVE -> ATTACK (`cve-attack`)

* IMPORTANT: Requires `cve-capec` mode to be run.

We can link CVEs to CAPECs by following the path CVE -> CWE -> CAPEC -> ATT&C

Firstly, we check all CVE->CAPEC relationships (where `_arango_cve_processor_note` = `cve-cwe` and source_ref is the CVE being considered).

This will return all the relationships between the CVE and CAPEC and thus the CAPEC object(s) STIX ID (as `target_refs`). We can then retrieve that STIX object(s) that will contain `external_references` listing ATT&CK IDs, which can then be looked up in CTI Butler

```
GET /api/v1/attack-enterprise/objects/?attack_id=<STIX ID>
```

All the ATT&CK STIX objects can then be imported to the CVE collection (`nvd_cve_vertex_collection`).

```sql
LET default_objects = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_arango_cve_processor_note": "imported from CTI Butler",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "<STIX DEFAULT OBJECT>"
    }
]
FOR default_object IN default_objects
INSERT default_object INTO <SOURCE>_vertex_collection
```

Then ACVEP creates an SRO as follows to link CVE to ATT&CK directly...

```json
{
    "type": "relationship",
    "spec_version": "2.1",
    "id": "relationship--<UUIDV5 GENERATION LOGIC>",
    "created_by_ref": "identity--152ecfe1-5015-522b-97e4-86b60c57036d",
    "created": "<vulnerabilities.cve.published>",
    "modified": "<vulnerabilities.cve.lastModifiedDate>",
    "relationship_type": "exploited-using",
    "source_ref": "vulnerability--<CVE VULNERABILITY OBJECT>",
    "target_ref": "<ATT&CK VULNERABILITY OBJECT>",
    "description": "<CVE name> <relationship_type without - char> <ATT&CK name>",
    "object_marking_refs": [
        "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
        "marking-definition--152ecfe1-5015-522b-97e4-86b60c57036d"
    ],
    "external_references": [
        {
            "source_name": "cve",
            "external_id": "<vulnerabilities.cve.id>",
            "url": "https://nvd.nist.gov/vuln/detail/<vulnerabilities.cve.id>"
        },
        {
            "url": "https://attack.mitre.org/techniques/<ID>",
            "external_id": "<ID>",
            "source_name": "mitre-attack"
        }
    ]
}
```

To generate the id of SRO, a UUIDv5 is generated using the namespace `152ecfe1-5015-522b-97e4-86b60c57036d` and the `relationship_type+ssource_ref+target_ref` values.

```sql
LET relationships = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_from": "nvd_cve_vertex_collection/vulnerability--<CVE VULNERABILITY OBJECT>",
        "_to": "nvd_cve_vertex_collection/<ATTACK OBJECT ID>",
        "_arango_cti_processor_note": "cve-attack",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS LAST MODIFIED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "_is_ref": false,
        "<STIX Relationship OBJECT PROPERTIES>"
    }
]
FOR relationship IN relationships
INSERT relationship INTO <SOURCE>_edge_collection
```