## CVE Vulnerability -> CWE Weakness Relationship (`cve-cwe`)

```json
    "external_references": [
        {
            "source_name": "cve",
            "url": "https://nvd.nist.gov/vuln/detail/CVE-2019-6535",
            "external_id": "CVE-2019-6535"
        },
        {
            "source_name": "cwe",
            "url": "https://cwe.mitre.org/data/definitions/CWE-400.html",
            "external_id": "CWE-400"
        },
        {
            "source_name": "cwe",
            "url": "https://cwe.mitre.org/data/definitions/CWE-400.html",
            "external_id": "CWE-400"
        },
        {
            "source_name": "ics-cert@hq.dhs.gov",
            "description": "Third Party Advisory,VDB Entry",
            "url": "http://www.securityfocus.com/bid/106771"
        },
```

You can find all CWE objects via the CTI Butler API 

```shell
GET /api/v1/cwe/objects/{cwe_id}/
```

All the CWE STIX objects can then be imported to the CVE collection (`nvd_cve_vertex_collection`).

```sql
LET default_objects = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_arango_cve_processor_note": "imported from CTI Butler",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "<STIX DEFAULT OBJECT>"
    }
]
FOR default_object IN default_objects
INSERT default_object INTO <SOURCE>_vertex_collection
```

A Relationship Object is created to join them with the following structure.

```json
{
    "type": "relationship",
    "spec_version": "2.1",
    "id": "relationship--<UUIDV5 GENERATION LOGIC>",
    "created_by_ref": "identity--152ecfe1-5015-522b-97e4-86b60c57036d",
    "created": "<vulnerabilities.cve.published>",
    "modified": "<vulnerabilities.cve.lastModifiedDate>",
    "relationship_type": "exploited-using",
    "source_ref": "vulnerability--<CVE VULNERABILITY OBJECT>",
    "target_ref": "weakness--<CWE VULNERABILITY OBJECT>",
    "description": "<CVE name> <relationship_type without - char> <CWE name>",
    "object_marking_refs": [
        "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
        "marking-definition--152ecfe1-5015-522b-97e4-86b60c57036d"
    ],
    "external_references": [
        {
            "source_name": "cve",
            "external_id": "<vulnerabilities.cve.id>",
            "url": "https://nvd.nist.gov/vuln/detail/<vulnerabilities.cve.id>"
        },
        {
            "source_name": "cwe",
            "url": "http://cwe.mitre.org/data/definitions/<ID WITHOUT CWE- PREFIX>.html",
            "external_id": "<ID>"
        }
    ]
}
```

To generate the id of SRO, a UUIDv5 is generated using the namespace `152ecfe1-5015-522b-97e4-86b60c57036d` and the `relationship_type+ssource_ref+target_ref` values.

All generated objects are stored in the source edge collection.

```sql
LET relationships = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_from": "nvd_cve_vertex_collection/vulnerability--<CVE VULNERABILITY OBJECT>",
        "_to": "nvd_cve_vertex_collection/weakness--<CWE VULNERABILITY OBJECT>",
        "_arango_cti_processor_note": "cve-cwe",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS LAST MODIFIED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "_is_ref": false,
        "<STIX Relationship OBJECT PROPERTIES>"
    }
]
FOR relationship IN relationships
INSERT relationship INTO <SOURCE>_edge_collection
```