## CVE -> EPSS (`cve-epss`)

EPSS data estimates the likelihood (probability) that a software vulnerability will be exploited in the wild.

EPSS data is downloaded at script runtime using the endpoint

```shell
GET https://epss.cyentia.com/epss_scores-YYYY-MM-DD.csv.gz
```

Where `YYYY-MM-DD` is the day the script was run.

And it is recorded as a Report SDO as follows;

```json
{
    "type": "report",
    "spec_version": "2.1",
    "id": "report--<UUIDV5 GENERATION LOGIC>",
    "created_by_ref": "identity--152ecfe1-5015-522b-97e4-86b60c57036d",
    "created": "<EARLIEST EPSS RECORDED in x_epss>",
    "modified": "<LATEST EPSS RECORDED in x_epss>",
    "published": "<EARLIEST EPSS RECORDED in x_epss>",
    "name": "EPSS Scores: <CVE ID>",
    "object_refs": [
        "vulnerability--<CVE-vuln-object>"
    ],
    "labels": [
        "epss"
    ],
    "object_marking_refs": [
        "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
        "marking-definition--identity--152ecfe1-5015-522b-97e4-86b60c57036d"
    ],
    "extensions": {
        "extension-definition--f80cce10-5ac0-58d1-9e7e-b4ed0cc4dbb9": {
            "extension_type": "toplevel-property-extension"
        }
    },
    "x_epss": [
        {
            "date": "<EPSS DATE>",
            "percentile": "<EPSS PERCENTILE>",
            "score": "<EPSS SCORE>"
        },
        {
            "date": "<EPSS DATE>",
            "percentile": "<EPSS PERCENTILE>",
            "score": "<EPSS SCORE>"
        }
    ],
    "external_references": [
        {
            "source_name": "cve",
            "external_id": "<vulnerabilities.cve.id>",
            "url": "https://nvd.nist.gov/vuln/detail/<vulnerabilities.cve.id>"
        }
    ]
}
```

To generate the id a UUIDv5 is generated using the namespace `152ecfe1-5015-522b-97e4-86b60c57036d` and the `name` values.

Each time the script is run on the CVE, the `x_epss` is appended to with the data for the new data.

As we are using custom properties, we define them using an extension defintion;

https://raw.githubusercontent.com/muchdogesec/stix2extensions/refs/heads/main/extension-definitions/properties/report-epss-scoring.json

This extension definition is imported and stored in each bundle generated. All objects can be imported to the DB as follows.

```sql
LET default_objects = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_arango_cve_processor_note": "imported from EPSS",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "<STIX DEFAULT OBJECT>"
    }
]
FOR default_object IN default_objects
INSERT default_object INTO <SOURCE>_vertex_collection
```
