## CVE -> KEV (`cve-kev`)

CISA maintain a list of known exploited vulnerabilities:

https://www.cisa.gov/sites/default/files/feeds/known_exploited_vulnerabilities.json

```json
    "vulnerabilities": [
        {
            "cveID": "CVE-2024-51378",
            "vendorProject": "CyberPersons",
            "product": "CyberPanel",
            "vulnerabilityName": "CyberPanel Incorrect Default Permissions Vulnerability",
            "dateAdded": "2024-12-04",
            "shortDescription": "CyberPanel contains an incorrect default permissions vulnerability that allows for authentication bypass and the execution of arbitrary commands using shell metacharacters in the statusfile property.",
            "requiredAction": "Apply mitigations per vendor instructions or discontinue use of the product if mitigations are unavailable.",
            "dueDate": "2024-12-25",
            "knownRansomwareCampaignUse": "Known",
            "notes": "https:\/\/cyberpanel.net\/KnowledgeBase\/home\/change-logs\/ ; https:\/\/nvd.nist.gov\/vuln\/detail\/CVE-2024-51378",
            "cwes": [
                "CWE-276"
            ]
        },
```
These are modelled as Report SDOs as follows;

```json
{
    "type": "report",
    "spec_version": "2.1",
    "id": "report--<UUIDV5 GENERATION LOGIC>",
    "created_by_ref": "identity--152ecfe1-5015-522b-97e4-86b60c57036d",
    "created": "<vulnerabilities.cve.published>",
    "modified": "<vulnerabilities.cve.lastModifiedDate>",
    "published": "<vulnerabilities.cve.published>",
    "name": "CISA KEV: <CVE ID>",
    "description": "<vulnerabilityName>\n\n<shortDescription>\n\nRequired action: <cisaRequiredAction>\n\nAction due by: <cisaActionDue>",
    "object_refs": [
        "vulnerability--<CVE ID>"
    ],
    "labels": [
        "kev"
    ],
    "external_references": [
        {
            "source_name": "cve",
            "external_id": "<vulnerabilities.cve.id>",
            "url": "https://nvd.nist.gov/vuln/detail/<vulnerabilities.cve.id>"
        }
    ],
    "object_marking_refs": [
        "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
        "marking-definition--152ecfe1-5015-522b-97e4-86b60c57036d"
    ],
}
```

To generate the id a UUIDv5 is generated using the namespace `152ecfe1-5015-522b-97e4-86b60c57036d` and the `name` values.

All objects can be imported to the DB as follows.

```sql
LET default_objects = [
    {
        "_key": "<THE OBJECTS STIX ID>",
        "_arango_cve_processor_note": "imported from KEV",
        "_record_created": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_modified": "<DATETIME OBJECT WAS INSERTED IN DB>",
        "_record_md5_hash": "<HASH OF OBJECT>",
        "_is_latest": true,
        "<STIX DEFAULT OBJECT>"
    }
]
FOR default_object IN default_objects
INSERT default_object INTO <SOURCE>_vertex_collection
```